@@ -1,7 +1,7 @@
 package JSON::RPC::Spec;
 use Moo;
 use Carp ();
-use version; our $VERSION = version->declare("v1.0.4");
+use version; our $VERSION = version->declare("v1.0.5");
 use Try::Tiny;
 use Router::Simple;
 use JSON::RPC::Spec::Procedure;
@@ -222,11 +222,11 @@ You can set the C<PERL_JSON_RPC_SPEC_DEBUG> environment variable to get some adv
 
 =head1 SEE ALSO
 
-http://search.cpan.org/dist/JSON-RPC/
+L<JSON::RPC>
 
-http://search.cpan.org/dist/JSON-RPC-Dispatcher/
+L<JSON::RPC::Dispatcher>
 
-http://search.cpan.org/dist/JSON-RPC-Common/
+L<JSON::RPC::Common>
 
 =head1 LICENSE
 
